@@ -310,38 +310,29 @@ async def present(
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     before = None
-    tags_list = None
-    tags_dict = None
-    if tags is not None:
-        if isinstance(tags, Dict):
-            tags_list = hub.tool.aws.tag_utils.convert_tag_dict_to_list(tags)
-            tags_dict = tags
-        else:
-            tags_list = tags
-            tags_dict = hub.tool.aws.tag_utils.convert_tag_list_to_dict(tags)
+
+    if isinstance(tags, List):
+        tags = hub.tool.aws.tag_utils.convert_tag_list_to_dict(tags)
+
     if resource_id:
-        before = await hub.exec.boto3.client.acm.describe_certificate(
-            ctx, CertificateArn=resource_id
+        before = await hub.exec.aws.acm.certificate_manager.get(
+            ctx,
+            name=name,
+            resource_id=resource_id,
         )
 
-    are_tags_updated = False
-    is_reimported = False
-    if before and before["result"]:
+        if not before["result"] or not before["ret"]:
+            result["comment"] = before["comment"]
+            result["result"] = False
+            return result
+
+        result["old_state"] = copy.deepcopy(before["ret"])
+        result["new_state"] = copy.deepcopy(result["old_state"])
+
+        are_tags_updated = False
+        is_reimported = False
+
         try:
-            convert_ret = (
-                await hub.tool.aws.acm.conversion_utils.convert_raw_acm_to_present(
-                    ctx,
-                    raw_resource=before["ret"].get("Certificate"),
-                    idem_resource_name=resource_id,
-                )
-            )
-            result["result"] = convert_ret["result"]
-            if not result["result"]:
-                result["comment"] = result["comment"] + convert_ret["comment"]
-            result["old_state"] = convert_ret.get("ret")
-            old_tag_list = hub.tool.aws.tag_utils.convert_tag_dict_to_list(
-                result["old_state"].get("tags")
-            )
             plan_state = copy.deepcopy(result["old_state"])
 
             # Reimport certificate if certificate arn,private key and certificate body is given as input
@@ -371,17 +362,13 @@ async def present(
                     result["comment"] = result["comment"] + (
                         f"Would reimport certificate for aws.acm.certificate_manager {name}",
                     )
-            if (
-                tags_list is not None
-                and not hub.tool.aws.state_comparison_utils.are_lists_identical(
-                    tags_list, old_tag_list
-                )
-            ):
+            if tags is not None and tags != result["old_state"].get("tags"):
+                # Update tags
                 update_tags_ret = await hub.tool.aws.acm.tag.update_tags(
                     ctx=ctx,
                     resource_id=resource_id,
-                    old_tags=old_tag_list,
-                    new_tags=tags_list,
+                    old_tags=result["old_state"].get("tags"),
+                    new_tags=tags,
                 )
                 if not update_tags_ret["result"]:
                     result["comment"] = result["comment"] + update_tags_ret["comment"]
@@ -419,7 +406,7 @@ async def present(
                             "certificate": certificate,
                             "private_key": private_key,
                             "certificate_chain": certificate_chain,
-                            "tags": tags_dict,
+                            "tags": tags,
                         },
                     )
                     result["comment"] = result["comment"] + (
@@ -431,7 +418,7 @@ async def present(
                     Certificate=certificate,
                     PrivateKey=private_key,
                     CertificateChain=certificate_chain,
-                    Tags=tags_list,
+                    Tags=hub.tool.aws.tag_utils.convert_tag_dict_to_list(tags),
                 )
                 result["result"] = imported["result"]
                 if not result["result"]:
@@ -452,7 +439,7 @@ async def present(
                     operation="DescribeCertificate",
                     argument=["Error.Code", "Certificate.Status"],
                     acceptors=acceptors,
-                    client=hub.tool.boto3.client.get_client(ctx, "acm"),
+                    client=await hub.tool.boto3.client.get_client(ctx, "acm"),
                 )
                 await hub.tool.boto3.client.wait(
                     ctx,
@@ -487,7 +474,7 @@ async def present(
                             "domain_validation_options": domain_validation_options,
                             "options": options,
                             "certificate_authority_arn": certificate_authority_arn,
-                            "tags": tags_dict,
+                            "tags": tags,
                         },
                     )
                     result["comment"] = result[
@@ -506,7 +493,7 @@ async def present(
                     DomainValidationOptions=domain_validation_options,
                     Options=options,
                     CertificateAuthorityArn=certificate_authority_arn,
-                    Tags=tags_list,
+                    Tags=hub.tool.aws.tag_utils.convert_tag_dict_to_list(tags),
                 )
                 result["result"] = requested["result"]
                 if not result["result"]:
@@ -526,7 +513,7 @@ async def present(
                     operation="DescribeCertificate",
                     argument=["Error.Code", "Certificate.Status"],
                     acceptors=acceptors,
-                    client=hub.tool.boto3.client.get_client(ctx, "acm"),
+                    client=await hub.tool.boto3.client.get_client(ctx, "acm"),
                 )
                 await hub.tool.boto3.client.wait(
                     ctx,
