@@ -1366,7 +1366,7 @@ async def absent(
             operation="DescribeAutoScalingGroups",
             argument=["AutoScalingGroups"],
             acceptors=delete_waiter_acceptors,
-            client=hub.tool.boto3.client.get_client(ctx, "autoscaling"),
+            client=await hub.tool.boto3.client.get_client(ctx, "autoscaling"),
         )
         try:
             await hub.tool.boto3.client.wait(
