@@ -1,4 +1,5 @@
 """State module for managing AWS Launch Configurations."""
+import base64
 import copy
 from dataclasses import field
 from dataclasses import make_dataclass
@@ -13,6 +14,7 @@ async def present(
     hub,
     ctx,
     name: str,
+    launch_config_name: str,
     resource_id: str = None,
     image_id: str = None,
     key_name: str = None,
@@ -77,7 +79,10 @@ async def present(
 
     Args:
         name(str):
-            The name of the launch configuration. This name must be unique per Region per account.
+            Idem name of the launch configuration.
+
+        launch_config_name(str):
+            The name of the aws launch configuration. This name must be unique per Region per account.
 
         resource_id(str, Optional):
             AWS Launch Configuration name.
@@ -328,6 +333,7 @@ async def present(
             [launch_configuration-resource-id]:
               aws.autoscaling.launch_configuration.present:
                 - name: 'string'
+                - launch_config_name: 'string'
                 - resource_id: 'string'
                 - image_id: 'string'
                 - key_name: 'string'
@@ -355,7 +361,8 @@ async def present(
             idem-test-launch_configuration:
               aws.autoscaling.launch_configuration.present:
                 - name: idem-test-launch_configuration
-                - resource_id: idem-test-launch_configuration
+                - launch_config_name: test-launch_configuration
+                - resource_id: test-launch_configuration
                 - image_id: ami-73949613
                 - key_name: test-n
                 - security_groups:
@@ -401,7 +408,8 @@ async def present(
     before = None
     desired_state = {
         "name": name,
-        "resource_id": name,
+        "resource_id": launch_config_name,
+        "launch_config_name": launch_config_name,
         "image_id": image_id,
         "key_name": key_name,
         "security_groups": security_groups,
@@ -423,7 +431,7 @@ async def present(
     }
 
     launch_conf_args = {
-        "LaunchConfigurationName": name,
+        "LaunchConfigurationName": launch_config_name,
         "ImageId": image_id,
         "KeyName": key_name,
         "SecurityGroups": security_groups,
@@ -486,7 +494,7 @@ async def present(
                 f"Created aws.autoscaling.launch_configuration '{name}'",
             )
             launch_configuration_created = True
-            resource_id = name
+            resource_id = launch_config_name
         except hub.tool.boto3.exception.ClientError as e:
             result["comment"] = result["comment"] + (f"{e.__class__.__name__}: {e}",)
             result["result"] = False
@@ -623,3 +631,15 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         }
 
     return result
+
+
+def pre_process_desired_state(hub, chunk):
+    desired_state = copy.deepcopy(chunk)
+    if desired_state.get("user_data"):
+        user_data = desired_state["user_data"]
+        desired_state["user_data"] = base64.b64encode(user_data.encode()).decode()
+
+    desired_state = hub.tool.aws.autoscaling.conversion_utils.handle_security_groups(
+        resource=desired_state
+    )
+    return desired_state
