@@ -118,12 +118,8 @@ async def present(
             only valid value for RI or Savings Plans utilization or coverage budgets. You can't use `budget_limit`
             with `planned_budget_limits` for `CreateBudget` and `UpdateBudget actions`.
 
-            * Amount (str) -- [REQUIRED]
-                The cost or usage amount that's associated with a budget forecast, actual spend, or budget threshold.
-
-            * Unit (str) -- [REQUIRED]
-                The unit of measurement that's used for the budget forecast, actual spend, or budget threshold,
-                such as USD or GBP.
+            * Amount (str): The cost or usage amount that's associated with a budget forecast, actual spend, or budget threshold.
+            * Unit (str): The unit of measurement that's used for the budget forecast, actual spend, or budget threshold, such as USD or GBP.
         planned_budget_limits(dict[str, Any], Optional):
             A map containing multiple `budget_limit`, including current or future limits.
 
@@ -138,31 +134,18 @@ async def present(
             is the start of the quarter, UTC in epoch seconds.
 
             If the planned budget expires before 12 months for monthly or four quarters for quarterly, provide the
-            PlannedBudgetLimits values only for the remaining periods.
-
-            If the budget begins at a date in the future, provide PlannedBudgetLimits values from the start date of the
-            budget.
-
-            After all the budget_limit values in planned_budget_limits are used, the budget continues to use the last
-            limit as the budget_limit. At that point, the planned budget provides the same experience as a fixed budget.
-
-            `DescribeBudget` and `DescribeBudgets` response along with `planned_budget_limits` also contain
-            `budget_limit` representing the current month or quarter limit present in `planned_budget_limits`. This
-            only applies to budgets that are created with `planned_budget_limits`. Budgets that are created without
-            `planned_budget_limits` only contain `budget_limit`. They don't contain `planned_budget_limits`.
+            PlannedBudgetLimits values only for the remaining periods. If the budget begins at a date in the future,
+            provide PlannedBudgetLimits values from the start date of the budget. After all the budget_limit values in
+            planned_budget_limits are used, the budget continues to use the last limit as the budget_limit. At that point,
+            the planned budget provides the same experience as a fixed budget.
 
             The amount of cost or usage that's measured for a budget.
 
-            For example, a Spend for 3 GB of S3 usage has the following parameters:
-              * An `Amount` of `3`
-              * A `unit` of `GB`
+            * Amount (str): The cost or usage amount that's associated with a budget forecast, actual spend, or budget
+            threshold.
 
-            * Amount (str):
-                The cost or usage amount that's associated with a budget forecast, actual spend, or budget threshold.
-
-            * Unit (str):
-                The unit of measurement that's used for the budget forecast, actual spend, or budget threshold, such as
-                USD or GBP.
+            * Unit (str): The unit of measurement that's used for the budget forecast, actual spend, or budget threshold,
+            such as USD or GBP.
         cost_filters(dict[str, list[str]], Optional):
             The cost filters, such as Region , Service , member account , Tag , or Cost Category , that are applied to
             a budget.
@@ -171,7 +154,7 @@ async def present(
               * Amazon EC2
               * Amazon Redshift
               * Amazon Relational Database Service
-              * Amazon ElastiCache
+              * Amazon ElasticCache
               * Amazon OpenSearch Service
         cost_types(dict[str, Any], Optional):
             The types of costs that are included in this COST budget.
@@ -179,38 +162,21 @@ async def present(
             USAGE, RI_UTILIZATION, RI_COVERAGE, SAVINGS_PLANS_UTILIZATION, and SAVINGS_PLANS_COVERAGE budgets do
             not have `cost_types`.
 
-            * IncludeTax (bool, Optional):
-                Specifies whether a budget includes taxes. The default value is true.
+            * IncludeTax (bool, Optional): Specifies whether a budget includes taxes. The default value is true.
+            * IncludeSubscription (bool, Optional): Specifies whether a budget includes subscriptions. The default value is true.
+            * UseBlended (bool, Optional): Specifies whether a budget uses a blended rate. The default value is false.
+            * IncludeRefund (bool, Optional): Specifies whether a budget includes refunds. The default value is true.
+            * IncludeCredit (bool, Optional): Specifies whether a budget includes credits. The default value is true.
+            * IncludeUpfront (bool, Optional): Specifies whether a budget includes upfront RI costs. The default value is true.
+            * IncludeRecurring (bool, Optional): Specifies whether a budget includes recurring fees such as monthly RI
+                fees. The default value is true.
+            * IncludeOtherSubscription (bool, Optional): Specifies whether a budget includes non-RI subscription costs.
+                The default value is true.
+            * IncludeSupport (bool, Optional): Specifies whether a budget includes support subscription fees. The
+                default value is true.
+            * IncludeDiscount (bool, Optional): Specifies whether a budget includes discounts. The default value is true.
+            * UseAmortized (bool, Optional): Specifies whether a budget uses the amortized rate. The default value is false.
 
-            * IncludeSubscription (bool, Optional):
-                Specifies whether a budget includes subscriptions. The default value is true.
-
-            * UseBlended (bool, Optional):
-                Specifies whether a budget uses a blended rate. The default value is false.
-
-            * IncludeRefund (bool, Optional):
-                Specifies whether a budget includes refunds. The default value is true.
-
-            * IncludeCredit (bool, Optional):
-                Specifies whether a budget includes credits. The default value is true.
-
-            * IncludeUpfront (bool, Optional):
-                Specifies whether a budget includes upfront RI costs. The default value is true.
-
-            * IncludeRecurring (bool, Optional):
-                Specifies whether a budget includes recurring fees such as monthly RI fees. The default value is true.
-
-            * IncludeOtherSubscription (bool, Optional):
-                Specifies whether a budget includes non-RI subscription costs. The default value is true.
-
-            * IncludeSupport (bool, Optional):
-                Specifies whether a budget includes support subscription fees. The default value is true.
-
-            * IncludeDiscount (bool, Optional):
-                Specifies whether a budget includes discounts. The default value is true.
-
-            * UseAmortized (bool, Optional):
-                Specifies whether a budget uses the amortized rate. The default value is false.
         time_period (dict[str, Any], Optional):
             The period of time that's covered by a budget. You set the start date and end date. The start
             date must come before the end date. The end date must come before `06/15/87 00:00 UTC`.
@@ -223,10 +189,8 @@ async def present(
             your end date to `06/15/87 00:00 UTC`. The defaults are the same for the Billing and Cost
             Management console and the API.
 
-            You can change either date with the `UpdateBudget` operation.
-
-            After the end date, Amazon Web Services deletes the budget and all the associated notifications
-            and subscribers.
+            You can change either date with the `UpdateBudget` operation. After the end date, Amazon Web Services deletes
+            the budget and all the associated notifications and subscribers.
 
             * Start (datetime, Optional):
                 The start date for a budget. If you created your budget and didn't specify a start date, Amazon
@@ -234,9 +198,8 @@ async def present(
                 ANNUALLY). For example, if you created your budget on January 24, 2018, chose `DAILY`, and didn't
                 set a start date, Amazon Web Services set your start date to `01/24/18 00:00 UTC`. If you chose
                 `MONTHLY`, Amazon Web Services set your start date to `01/01/18 00:00 UTC`. The defaults are the
-                same for the Billing and Cost Management console and the API.
-
-                You can change your start date with the `UpdateBudget` operation.
+                same for the Billing and Cost Management console and the API. You can change your start date with the
+                `UpdateBudget` operation.
 
             * End (datetime, Optional):
                 The end date for a budget. If you didn't specify an end date, Amazon Web Services set your end date to
@@ -247,13 +210,13 @@ async def present(
         auto_adjust_data (dict[str, Any], Optional):
             The parameters that determine the budget amount for an auto-adjusting budget.
 
-            * AutoAdjustType (str):-- [REQUIRED]
+            * AutoAdjustType (str):
                 The string that defines whether your budget auto-adjusts based on historical or forecasted data.
 
-            * HistoricalOptions (dict[str, Any], Optional): --
+            * HistoricalOptions (dict[str, Any], Optional):
                 The parameters that define or describe the historical data that your auto-adjusting budget is based on.
 
-                * BudgetAdjustmentPeriod (int) -- [REQUIRED]
+                * BudgetAdjustmentPeriod (int):
                     The number of budget periods included in the moving-average calculation that determines your
                     auto-adjusted budget amount.
                     The maximum value depends on the `time_unit` granularity of the budget:
@@ -263,7 +226,7 @@ async def present(
                     * For the `QUARTERLY` granularity, the maximum value is `4`.
                     * For the `ANNUALLY` granularity, the maximum value is `1`.
 
-                * LookBackAvailablePeriods (int) --
+                * LookBackAvailablePeriods (int):
                     The integer that describes how many budget periods in your `BudgetAdjustmentPeriod` are included in
                     the calculation of your current `BudgetLimit`. If the first budget period in your
                     `BudgetAdjustmentPeriod` has no cost data, then that budget period isn’t included in the average
@@ -276,8 +239,9 @@ async def present(
                     You can’t set your own LookBackAvailablePeriods. The value is automatically calculated from the
                     BudgetAdjustmentPeriod and your historical cost data.
 
-            * LastAutoAdjustTime (datetime) --
+            * LastAutoAdjustTime (datetime):
                 The last time that your budget was auto-adjusted.
+
         notifications_with_subscribers(list[dict[str, Any]], Optional):
             A notification that you want to associate with a budget. A budget can have up to five notifications, and
             each notification can have one SNS subscriber and up to 10 email subscribers. If you include notifications
@@ -287,22 +251,20 @@ async def present(
             A notification with subscribers can have one SNS subscriber and up to 10 email subscribers, for a total of
             11 subscribers.
 
-            * Notification (dict[str, Any]): -- [REQUIRED]
-                The notification that's associated with a budget.
+            * Notification (dict[str, Any]): The notification that's associated with a budget.
 
-                * NotificationType (str) -- [REQUIRED]
+                * NotificationType (str):
                     Specifies whether the notification is for how much you have spent (ACTUAL) or for how much that
                     you're forecasted to spend (FORECASTED).
 
-                * ComparisonOperator (str) -- [REQUIRED]
-                    The comparison that's used for this notification.
+                * ComparisonOperator (str): The comparison that's used for this notification.
 
-                * Threshold (float) -- [REQUIRED]
+                * Threshold (float):
                     The threshold that's associated with a notification. Thresholds are always a percentage, and many
                     customers find value being alerted between 50% - 200% of the budgeted amount. The maximum limit for
                     your threshold is 1,000,000% above the budgeted amount.
 
-                * ThresholdType (str) --
+                * ThresholdType (str):
                     The type of threshold for a notification. For `ABSOLUTE_VALUE` thresholds, Amazon Web Services
                     notifies you when you go over or are forecasted to go over your total cost threshold. For
                     `PERCENTAGE` thresholds, Amazon Web Services notifies you when you go over or are forecasted to go
@@ -310,11 +272,11 @@ async def present(
                     dollars, and you have a `PERCENTAGE` threshold of 80%, Amazon Web Services notifies you when you go
                     over 160 dollars.
 
-                * NotificationState (str) --
+                * NotificationState (str):
                     Specifies whether this notification is in alarm. If a budget notification is in the `ALARM` state,
                     you passed the set threshold for the budget.
 
-            * Subscribers (list[dict[str, Any]]): -- [REQUIRED]
+            * Subscribers (list[dict[str, Any]]):
                 A list of subscribers who are subscribed to this notification.
 
                 The subscriber to a budget notification consists of a subscription type and either an Amazon SNS topic
@@ -324,12 +286,10 @@ async def present(
                   * A `subscriptionType` of `EMAIL`
                   * An `address` of `example@example.com`
 
-                * SubscriptionType (str) -- [REQUIRED]
-                    The type of notification that Amazon Web Services sends to a subscriber.
+                * SubscriptionType (str): The type of notification that Amazon Web Services sends to a subscriber.
 
-                * Address (str) -- [REQUIRED]
+                * Address (str):
                     The address that Amazon Web Services sends budget notifications to, either an SNS topic or an email.
-
                     When you create a subscriber, the value of `Address` can't contain line breaks.
 
 
@@ -382,7 +342,6 @@ async def present(
 
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
-    before = None
     account_details = await hub.exec.boto3.client.sts.get_caller_identity(ctx)
     account_id = account_details["ret"]["Account"]
     resource_updated = False
@@ -404,29 +363,24 @@ async def present(
         budget_parameters["AutoAdjustData"] = auto_adjust_data
 
     if resource_id:
-        before = await hub.exec.boto3.client.budgets.describe_budget(
-            ctx, AccountId=account_id, BudgetName=resource_id
+        before = await hub.exec.aws.budgets.budget.get(
+            ctx, name=name, resource_id=resource_id
         )
-        if not before["result"]:
+        if not before["result"] or not before["ret"]:
             result["result"] = False
             result["comment"] = before["comment"]
             return result
 
-    if before:
-        result[
-            "old_state"
-        ] = await hub.tool.aws.budgets.conversion_utils.convert_raw_budget_to_present(
-            ctx,
-            account_id=account_id,
-            raw_resource=before["ret"]["Budget"],
-            idem_resource_name=name,
+        result["comment"] = hub.tool.aws.comment_utils.already_exists_comment(
+            resource_type="aws.budgets.budget", name=name
         )
-        plan_state = copy.deepcopy(result["old_state"])
+        result["old_state"] = copy.deepcopy(before["ret"])
+        result["new_state"] = copy.deepcopy(result["old_state"])
 
         update_ret = await hub.tool.aws.budgets.budget.update_budget(
             ctx,
             account_id=account_id,
-            before=before["ret"]["Budget"],
+            before=before["ret"],
             budget_limit=budget_limit,
             planned_budget_limits=planned_budget_limits,
             cost_filters=cost_filters,
@@ -437,26 +391,26 @@ async def present(
             auto_adjust_data=auto_adjust_data,
         )
         result["comment"] += update_ret["comment"]
-        result["result"] = update_ret["result"]
+        if not update_ret["result"]:
+            result["result"] = False
+            return result
+
         resource_updated = resource_updated or bool(update_ret["ret"])
         if update_ret["ret"] and ctx.get("test", False):
-            plan_state = update_ret["ret"]
+            result["new_state"].update(update_ret["ret"])
+            result["comment"] += hub.tool.aws.comment_utils.would_update_comment(
+                resource_type="aws.budgets.budget", name=name
+            )
+        if resource_updated and ctx.get("test", False):
+            return result
 
-        if resource_updated:
-            if ctx.get("test", False):
-                result["comment"] += hub.tool.aws.comment_utils.would_update_comment(
-                    resource_type="aws.budgets.budget", name=name
-                )
-            else:
-                result["comment"] += hub.tool.aws.comment_utils.update_comment(
-                    resource_type="aws.budgets.budget", name=name
-                )
     else:
         if ctx.get("test", False):
             result["new_state"] = hub.tool.aws.test_state_utils.generate_test_state(
                 enforced_state={},
                 desired_state={
                     "name": name,
+                    "resource_id": budget_name,
                     "budget_name": budget_name,
                     "budget_limit": budget_limit,
                     "cost_filters": cost_filters,
@@ -472,44 +426,32 @@ async def present(
                 resource_type="aws.budgets.budget", name=name
             )
             return result
-        ret = await hub.exec.boto3.client.budgets.create_budget(
+        create_ret = await hub.exec.boto3.client.budgets.create_budget(
             ctx,
             AccountId=account_id,
             Budget=budget_parameters,
             NotificationsWithSubscribers=notifications_with_subscribers,
         )
-        result["result"] = ret["result"]
-        if not result["result"]:
-            result["comment"] = ret["comment"]
+        if not create_ret["result"]:
+            result["result"] = False
+            result["comment"] = create_ret["comment"]
             return result
+
         result["comment"] = hub.tool.aws.comment_utils.create_comment(
             resource_type="aws.budgets.budget", name=name
         )
+        resource_id = budget_name
+
+    if (not result["old_state"]) or resource_updated:
+        after_ret = await hub.exec.aws.budgets.budget.get(
+            ctx, name=name, resource_id=resource_id
+        )
+        if not after_ret["result"] or not after_ret["ret"]:
+            result["result"] = False
+            result["comment"] += tuple(after_ret["comment"])
+            return result
+        result["new_state"] = after_ret["ret"]
 
-    try:
-        if ctx.get("test", False):
-            result["new_state"] = plan_state
-        elif (not before) or resource_updated:
-            after = await hub.exec.boto3.client.budgets.describe_budget(
-                ctx, AccountId=account_id, BudgetName=budget_name
-            )
-            if not after["result"]:
-                result["result"] = False
-                result["comment"] = after["comment"]
-                return result
-            result[
-                "new_state"
-            ] = await hub.tool.aws.budgets.conversion_utils.convert_raw_budget_to_present(
-                ctx,
-                account_id=account_id,
-                raw_resource=after["ret"]["Budget"],
-                idem_resource_name=name,
-            )
-        else:
-            result["new_state"] = copy.deepcopy(result["old_state"])
-    except Exception as e:
-        result["comment"] = result["comment"] + (str(e),)
-        result["result"] = False
     return result
 
 
@@ -550,43 +492,35 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
         )
         return result
 
-    before = await hub.exec.boto3.client.budgets.describe_budget(
-        ctx, AccountId=account_id, BudgetName=name
+    before = await hub.exec.aws.budgets.budget.get(
+        ctx, name=name, resource_id=resource_id
     )
 
-    if not before:
+    if not before["result"]:
+        result["comment"] = before["comment"]
+        result["result"] = False
+        return result
+
+    if not before["ret"]:
         result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
             resource_type="aws.budgets.budget", name=name
         )
     elif ctx.get("test", False):
-        result[
-            "old_state"
-        ] = await hub.tool.aws.budgets.conversion_utils.convert_raw_budget_to_present(
-            ctx,
-            account_id=account_id,
-            raw_resource=before["ret"]["Budget"],
-            idem_resource_name=name,
-        )
+        result["old_state"] = before["ret"]
         result["comment"] = hub.tool.aws.comment_utils.would_delete_comment(
             resource_type="aws.budgets.budget", name=name
         )
         return result
     else:
-        result[
-            "old_state"
-        ] = await hub.tool.aws.budgets.conversion_utils.convert_raw_budget_to_present(
-            ctx,
-            account_id=account_id,
-            raw_resource=before["ret"]["Budget"],
-            idem_resource_name=name,
-        )
-        ret = await hub.exec.boto3.client.budgets.delete_budget(
+        result["old_state"] = before["ret"]
+        delete_ret = await hub.exec.boto3.client.budgets.delete_budget(
             ctx, AccountId=account_id, BudgetName=name
         )
-        result["result"] = ret["result"]
-        if not result["result"]:
-            result["comment"] = ret["comment"]
+        if not delete_ret["result"]:
+            result["result"] = False
+            result["comment"] = delete_ret["comment"]
             return result
+
         result["comment"] = hub.tool.aws.comment_utils.delete_comment(
             resource_type="aws.budgets.budget", name=name
         )
@@ -608,30 +542,17 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
             $ idem describe aws.budgets.budget
     """
     result = {}
-    account_details = await hub.exec.boto3.client.sts.get_caller_identity(ctx)
-    account_id = account_details["ret"]["Account"]
-    ret = await hub.exec.boto3.client.budgets.describe_budgets(
-        ctx, AccountId=account_id
-    )
-
+    ret = await hub.exec.aws.budgets.budget.list(ctx)
     if not ret["result"]:
         hub.log.debug(f"Could not describe budgets {ret['comment']}")
         return {}
 
-    for budget in ret["ret"]["Budgets"]:
-        resource_id = budget.get("BudgetName")
-        resource_translated = (
-            await hub.tool.aws.budgets.conversion_utils.convert_raw_budget_to_present(
-                ctx,
-                account_id=account_id,
-                raw_resource=budget,
-                idem_resource_name=resource_id,
-            )
-        )
+    for budget in ret["ret"]:
+        resource_id = budget.get("resource_id")
         result[resource_id] = {
             "aws.budgets.budget.present": [
                 {parameter_key: parameter_value}
-                for parameter_key, parameter_value in resource_translated.items()
+                for parameter_key, parameter_value in budget.items()
             ]
         }
     return result
