@@ -472,7 +472,7 @@ async def present(
     }
 
     if resource_id:
-        resource = hub.tool.boto3.resource.create(
+        resource = await hub.tool.boto3.resource.create(
             ctx, "cloudwatch", "Alarm", resource_id
         )
         before = await hub.tool.boto3.resource.describe(resource)
@@ -588,7 +588,9 @@ async def present(
         if ctx.get("test", False):
             result["new_state"] = plan_state
         elif (not before) or resource_updated:
-            resource = hub.tool.boto3.resource.create(ctx, "cloudwatch", "Alarm", name)
+            resource = await hub.tool.boto3.resource.create(
+                ctx, "cloudwatch", "Alarm", name
+            )
             after = await hub.tool.boto3.resource.describe(resource)
             convert_ret = await hub.tool.aws.cloudwatch.conversion_utils.convert_raw_metric_alarm_to_present(
                 ctx, raw_resource=after, idem_resource_name=name
@@ -642,7 +644,9 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
             resource_type=RESOURCE_TYPE, name=name
         )
         return result
-    resource = hub.tool.boto3.resource.create(ctx, "cloudwatch", "Alarm", resource_id)
+    resource = await hub.tool.boto3.resource.create(
+        ctx, "cloudwatch", "Alarm", resource_id
+    )
     before = await hub.tool.boto3.resource.describe(resource)
 
     if not before:
