@@ -229,8 +229,7 @@ async def present(
               - virtualization_type: "string"
               - boot_mode: legacy-bios|uefi
               - tags:
-                  - Key: "string"
-                    Value: "string"
+                  'string': 'string'
               - resource_id: "string"
 
     Returns:
@@ -321,7 +320,7 @@ async def present(
         # update (we can only update tags and description)
         if tags is not None and tags != result["old_state"].get("tags"):
             # Update tags
-            update_ret = await hub.exec.aws.ec2.tag.update_tags(
+            update_ret = await hub.tool.aws.ec2.tag.update_tags(
                 ctx=ctx,
                 resource_id=resource_id,
                 old_tags=result["old_state"].get("tags"),
@@ -634,6 +633,7 @@ async def search(
         return result
 
     resource = ret["ret"]["Images"][0]
+    result["comment"] = (f'Found aws.ec2.ami resource {resource.get("ImageId")}',)
     if len(ret["ret"]["Images"]) > 1:
         if most_recent:
             ret["ret"]["Images"].sort(
