@@ -72,7 +72,7 @@ async def present(
             result["result"] = False
             return result
 
-    resource = hub.tool.boto3.resource.create(
+    resource = await hub.tool.boto3.resource.create(
         ctx,
         "ec2",
         "DhcpOptions",
@@ -201,7 +201,7 @@ async def absent(
             ] = f"Incorrect aws.ec2.dhcp_option_association resource_id: {resource_id}. Expected id {dhcp_id}-{vpc_id}"
             result["result"] = False
             return result
-    resource = hub.tool.boto3.resource.create(ctx, "ec2", "DhcpOptions", dhcp_id)
+    resource = await hub.tool.boto3.resource.create(ctx, "ec2", "DhcpOptions", dhcp_id)
     before = await hub.tool.boto3.resource.describe(resource)
     if not before:
         result["result"] = False
