@@ -133,7 +133,7 @@ async def present(
                 allocation_id = before["ret"]["allocation_id"]
             old_tags = result["old_state"].get("tags")
             if tags is not None and tags != old_tags:
-                update_ret = await hub.exec.aws.ec2.tag.update_tags(
+                update_ret = await hub.tool.aws.ec2.tag.update_tags(
                     ctx=ctx,
                     resource_id=allocation_id,
                     old_tags=old_tags,
