@@ -164,7 +164,7 @@ async def present(
                 tags_dict, old_tags
             ):
                 result["comment"] = f"'{name}' already exists. Updating tags"
-                update_ret = await hub.exec.aws.ec2.tag.update_tags(
+                update_ret = await hub.tool.aws.ec2.tag.update_tags(
                     ctx,
                     resource_id=resource_id,
                     old_tags=old_tags,
