@@ -701,7 +701,9 @@ async def present(
 
     if resource_id:
         # Assume that the instance already exists since we have a resource_id
-        resource = hub.tool.boto3.resource.create(ctx, "ec2", "Instance", resource_id)
+        resource = await hub.tool.boto3.resource.create(
+            ctx, "ec2", "Instance", resource_id
+        )
         get = await hub.exec.aws.ec2.instance.get(
             ctx, name=name, resource_id=resource_id
         )
@@ -926,7 +928,9 @@ async def present(
     if ctx.test:
         result["new_state"] = hub.tool.aws.ec2.instance.state.test(**desired_state)
     else:
-        resource = hub.tool.boto3.resource.create(ctx, "ec2", "Instance", resource_id)
+        resource = await hub.tool.boto3.resource.create(
+            ctx, "ec2", "Instance", resource_id
+        )
         hub.log.debug(f"Waiting for instance '{resource.id}' to be created")
         try:
             await hub.tool.boto3.resource.exec(resource, "wait_until_exists")
