@@ -145,7 +145,7 @@ async def present(
     updated_vals = {}
     before = None
     if resource_id is not None:
-        before = await hub.exec.boto3.client.kms.describe_key(ctx, KeyId=resource_id)
+        before = await hub.exec.aws.kms.key.get(ctx, name=name, resource_id=resource_id)
 
     if isinstance(tags, List):
         tags = hub.tool.aws.tag_utils.convert_tag_list_to_dict_tagkey(tags)
@@ -155,11 +155,7 @@ async def present(
     if before and before["result"]:
         result["comment"] = (f"aws.kms.key '{name}' already exists.",)
         try:
-            result[
-                "old_state"
-            ] = await hub.tool.aws.kms.conversion_utils.convert_raw_key_to_present(
-                ctx, raw_resource=before["ret"]["KeyMetadata"]
-            )
+            result["old_state"] = copy.deepcopy(before["ret"])
         except Exception as e:
             result["comment"] = result["comment"] + (str(e),)
             result["result"] = False
@@ -390,19 +386,14 @@ async def present(
 
             result["new_state"] = wait_updates_res["ret"]
         else:
-            try:
-                after = await hub.exec.boto3.client.kms.describe_key(
-                    ctx, KeyId=resource_id
-                )
-                if after.get("ret"):
-                    result[
-                        "new_state"
-                    ] = await hub.tool.aws.kms.conversion_utils.convert_raw_key_to_present(
-                        ctx, raw_resource=after["ret"].get("KeyMetadata", None)
-                    )
-            except Exception as e:
-                result["comment"] = result["comment"] + (str(e),)
+            after = await hub.exec.aws.kms.key.get(
+                ctx, name=name, resource_id=resource_id
+            )
+            if not after["result"]:
                 result["result"] = False
+                result["comment"] = after["comment"]
+                return result
+            result["new_state"] = copy.deepcopy(after["ret"])
 
     return result
 
@@ -456,7 +447,7 @@ async def absent(
             resource_type="aws.kms.key", name=name
         )
         return result
-    before = await hub.exec.boto3.client.kms.describe_key(ctx, KeyId=resource_id)
+    before = await hub.exec.aws.kms.key.get(ctx, name=name, resource_id=resource_id)
 
     if not before:
         result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
@@ -464,18 +455,9 @@ async def absent(
         )
         return result
     else:
-        try:
-            result[
-                "old_state"
-            ] = await hub.tool.aws.kms.conversion_utils.convert_raw_key_to_present(
-                ctx, raw_resource=before["ret"]["KeyMetadata"]
-            )
-        except Exception as e:
-            result["comment"] = (str(e),)
-            result["result"] = False
-            return result
+        result["old_state"] = copy.deepcopy(before["ret"])
 
-        if before["ret"]["KeyMetadata"].get("DeletionDate", None):
+        if before["ret"].get("deletion_date", None):
             result["comment"] = (
                 f"aws.kms.key '{resource_id}' already scheduled to be deleted in '{pending_window_in_days}' days",
             )
@@ -506,15 +488,14 @@ async def absent(
             result["comment"] = (f"{e.__class__.__name__}: {e}",)
 
     try:
-        after = await hub.exec.boto3.client.kms.describe_key(
-            ctx, KeyId=(resource_id if resource_id else name)
+        after = await hub.exec.aws.kms.key.get(
+            ctx, name=name, resource_id=(resource_id if resource_id else name)
         )
-        if after.get("ret"):
-            result[
-                "new_state"
-            ] = await hub.tool.aws.kms.conversion_utils.convert_raw_key_to_present(
-                ctx, raw_resource=after["ret"]["KeyMetadata"]
-            )
+        if not after["result"]:
+            result["result"] = False
+            result["comment"] = after["comment"]
+            return result
+        result["new_state"] = copy.deepcopy(after["ret"])
     except Exception as e:
         result["comment"] = result["comment"] + (str(e),)
         result["result"] = False
