@@ -831,7 +831,7 @@ async def present(
                     operation="DescribeDBClusters",
                     argument=["DBClusters[].Status"],
                     acceptors=update_waiter_acceptors,
-                    client=hub.tool.boto3.client.get_client(ctx, "rds"),
+                    client=await hub.tool.boto3.client.get_client(ctx, "rds"),
                 )
                 try:
                     await hub.tool.boto3.client.wait(
@@ -979,7 +979,7 @@ async def present(
             operation="DescribeDBClusters",
             argument=["DBClusters[].Status"],
             acceptors=create_waiter_acceptors,
-            client=hub.tool.boto3.client.get_client(ctx, "rds"),
+            client=await hub.tool.boto3.client.get_client(ctx, "rds"),
         )
         try:
             await hub.tool.boto3.client.wait(
@@ -1029,7 +1029,7 @@ async def present(
                 operation="DescribeDBClusters",
                 argument=["DBClusters[].Status"],
                 acceptors=update_waiter_acceptors,
-                client=hub.tool.boto3.client.get_client(ctx, "rds"),
+                client=await hub.tool.boto3.client.get_client(ctx, "rds"),
             )
             try:
                 await hub.tool.boto3.client.wait(
@@ -1166,7 +1166,7 @@ async def absent(
             operation="DescribeDBClusters",
             argument=["Error.Code", "DBClusters[].Status"],
             acceptors=delete_waiter_acceptors,
-            client=hub.tool.boto3.client.get_client(ctx, "rds"),
+            client=await hub.tool.boto3.client.get_client(ctx, "rds"),
         )
         try:
             await hub.tool.boto3.client.wait(
