@@ -1,3 +1,4 @@
+"""State module for managing Route53 Hosted zones."""
 import copy
 from dataclasses import field
 from dataclasses import make_dataclass
@@ -37,94 +38,120 @@ async def present(
         make_dataclass("Tag", [("Key", str), ("Value", str, field(default=None))])
     ] = None,
 ) -> Dict[str, Any]:
-    r"""
-        Creates a new public or private hosted zone. You create records in a public hosted zone to define how you want
-        to route traffic on the internet for a domain, such as example.com, and its subdomains (apex.example.com,
-        acme.example.com). You create records in a private hosted zone to define how you want to route traffic for a
-        domain and its subdomains within one or more Amazon Virtual Private Clouds (Amazon VPCs).   You can't convert a
-        public hosted zone to a private hosted zone or vice versa. Instead, you must create a new hosted zone with the
-        same name and create new resource record sets.  For more information about charges for hosted zones, see Amazon
-        Route 53 Pricing. Note the following:   You can't create a hosted zone for a top-level domain (TLD) such as
-        .com.   For public hosted zones, Route 53 automatically creates a default SOA record and four NS records for the
-        zone. For more information about SOA and NS records, see NS and SOA Records that Route 53 Creates for a Hosted
-        Zone in the Amazon Route 53 Developer Guide. If you want to use the same name servers for multiple public hosted
-        zones, you can optionally associate a reusable delegation set with the hosted zone. See the DelegationSetId
-        element.   If your domain is registered with a registrar other than Route 53, you must update the name servers
-        with your registrar to make Route 53 the DNS service for the domain. For more information, see Migrating DNS
-        Service for an Existing Domain to Amazon Route 53 in the Amazon Route 53 Developer Guide.    When you submit a
-        CreateHostedZone request, the initial status of the hosted zone is PENDING. For public hosted zones, this means
-        that the NS and SOA records are not yet available on all Route 53 DNS servers. When the NS and SOA records are
-        available, the status of the zone changes to INSYNC. The CreateHostedZone request requires the caller to have an
-        ec2:DescribeVpcs permission.
+    """Creates a new public or private hosted zone.
 
-        Args:
-            name(Text): An Idem name of the hosted zone resource.
-            hosted_zone_name(Text): A unique string that identifies a hosted zone.
-            caller_reference(Text): A unique string that identifies the request and that allows failed CreateHostedZone
-                                      requests to be retried without the risk of executing the operation twice.
-                                      You must use a unique CallerReference string every time you submit a CreateHostedZone request.
-                                      CallerReference can be any unique string, for example, a date/time stamp.,
-            resource_id(Text, optional): AWS route53 hosted zone ID.
-            config(Dict[str, Any], optional): (Optional) A complex type that contains the following optional values:   For public and private
-                hosted zones, an optional comment   For private hosted zones, an optional PrivateZone element
-                If you don't specify a comment or the PrivateZone element, omit HostedZoneConfig and the other
-                elements. Defaults to None.
-                * Comment (str, optional): Any comments that you want to include about the hosted zone.
-                * PrivateZone (bool, optional): A value that indicates whether this is a private hosted zone.
-            vpcs(List, optional): (Private hosted zones only) A list that contains information about the Amazon VPC's that
-                you're associating with this hosted zone. If you are associating VPC's with a hosted zone with this request, the
-                paramaters VPCId and VPCRegion are also required. To associate additional Amazon VPCs with the
-                hosted zone, use AssociateVPCWithHostedZone after you create a hosted zone. Defaults to None.
-                * VPCRegion (str, optional): (Private hosted zones only) The region that an Amazon VPC was created in.
-                * VPCId (str, optional): (Private hosted zones only) The ID of an Amazon VPC.
-            delegation_set_id(string, optional): Id of a reusable delegation set,
-            tags(List or Dict, optional): list of tags in the format of [{"Key": tag-key, "Value": tag-value}] or dict in the format of
-                {tag-key: tag-value} The tags to assign to the hosted zone. Defaults to None.
-                * Key (Text) -- The key of the tag. Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with aws: .
-                * Value (Text) -- The value of the tag. Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
+    You create records in a public hosted zone to define how you want to route traffic on the internet for a domain, such
+    as example.com, and its subdomains (apex.example.com, acme.example.com). You create records in a private hosted zone
+    to define how you want to route traffic for a domain and its subdomains within one or more Amazon Virtual Private Clouds
+    (Amazon VPCs). You can't convert a public hosted zone to a private hosted zone or vice versa. Instead, you must
+    create a new hosted zone with the same name and create new resource record sets.  For more information about charges
+    for hosted zones, see Amazon Route 53 Pricing.
+
+    Note the following: You can't create a hosted zone for a top-level domain (TLD) such as .com.   For public hosted
+    zones, Route 53 automatically creates a default SOA record and four NS records for the zone. For more information
+    about SOA and NS records, see NS and SOA Records that Route 53 Creates for a Hosted Zone in the Amazon Route 53
+    Developer Guide. If you want to use the same name servers for multiple public hosted zones, you can optionally
+    associate a reusable delegation set with the hosted zone. See the DelegationSetId element.   If your domain is
+    registered with a registrar other than Route 53, you must update the name servers with your registrar to make Route 53
+    the DNS service for the domain. For more information, see Migrating DNS Service for an Existing Domain to Amazon
+    Route 53 in the Amazon Route 53 Developer Guide. When you submit a CreateHostedZone request, the initial status of
+    the hosted zone is PENDING. For public hosted zones, this means that the NS and SOA records are not yet available on
+    all Route 53 DNS servers. When the NS and SOA records are available, the status of the zone changes to INSYNC. The
+    CreateHostedZone request requires the caller to have an ec2:DescribeVpcs permission.
+
+    Args:
+        name(str):
+            An Idem name of the hosted zone resource.
+
+        hosted_zone_name(str):
+            A unique string that identifies a hosted zone.
+
+        caller_reference(str):
+            A unique string that identifies the request and that allows failed CreateHostedZone
+            requests to be retried without the risk of executing the operation twice.
+            You must use a unique CallerReference string every time you submit a CreateHostedZone request.
+            CallerReference can be any unique string, for example, a date/time stamp.,
+
+        resource_id(str, Optional):
+            AWS route53 hosted zone ID.
+
+        config(dict[str, Any], Optional):
+            A complex type that contains the following optional values:   For public and private
+            hosted zones, an optional comment   For private hosted zones, an optional PrivateZone element
+            If you don't specify a comment or the PrivateZone element, omit HostedZoneConfig and the other
+            elements. Defaults to None.
+
+            * Comment (str, Optional):
+                Any comments that you want to include about the hosted zone.
+            * PrivateZone (bool, Optional):
+                A value that indicates whether this is a private hosted zone.
+
+        vpcs(list, Optional):
+            (Private hosted zones only) A list that contains information about the Amazon VPC's that
+            you're associating with this hosted zone. If you are associating VPC's with a hosted zone with this request, the
+            paramaters VPCId and VPCRegion are also required. To associate additional Amazon VPCs with the
+            hosted zone, use AssociateVPCWithHostedZone after you create a hosted zone. Defaults to None.
+
+            * VPCRegion (str, Optional):
+                (Private hosted zones only) The region that an Amazon VPC was created in.
+            * VPCId (str, Optional):
+                (Private hosted zones only) The ID of an Amazon VPC.
+
+        delegation_set_id(str, Optional):
+            Id of a reusable delegation set,
+
+        tags(list or dict, Optional):
+            list of tags in the format of ``[{"Key": tag-key, "Value": tag-value}]`` or dict in the format of
+            ``{tag-key: tag-value}`` The tags to assign to the hosted zone. Defaults to None.
+
+            * Key (str):
+                The key of the tag. Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with aws: .
+            * Value (str):
+                The value of the tag. Tag values are case-sensitive and accept a maximum of 255 Unicode characters.
 
 
-            Request Syntax:
+    Request Syntax:
+        .. code-block:: sls
+
             [hosted_zone_id]:
               aws.route53.hosted_zone.present:
-              - name: 'string'
-              - hosted_zone_name: 'string'
-              - resource_id: 'string'
-              - caller_reference: 'string'
-              - config:
-                  PrivateZone: 'string'
-                  Comment: 'string'
-              - vpcs:
-                - VPCId: 'string'
-                  VPCRegion: 'string'
-              - delegation_set_id: 'string'
-    -         - tags:
-                - Key: 'string'
-                  Value: 'string'
+                - name: 'string'
+                - hosted_zone_name: 'string'
+                - resource_id: 'string'
+                - caller_reference: 'string'
+                - config:
+                    PrivateZone: 'string'
+                    Comment: 'string'
+                - vpcs:
+                  - VPCId: 'string'
+                    VPCRegion: 'string'
+                - delegation_set_id: 'string'
+                - tags:
+                    - Key: 'string'
+                      Value: 'string'
 
-        Returns:
-            Dict[str, Any]
+    Returns:
+        Dict[str, Any]
 
-        Examples:
+    Examples:
+        .. code-block:: sls
 
-            .. code-block:: sls
-
-                resource_is_present:
-                  aws.route53.hosted_zone.present:
-                    - name: value
-                    - hosted_zone_name: value
-                    - resource_id: value
-                    - caller_reference: value
-                    - config:
-                        PrivateZone: True
-                        Comment: 'description of hosted zone config'
-                    - vpcs:
-                        - VPCId: 'vpc id'
-                          VPCRegion: 'us-east1'
-                    - delegation_set_id: 'string'
-    -               - tags:
-                        - Key: 'tag key'
-                          Value: 'tag value'
+            resource_is_present:
+              aws.route53.hosted_zone.present:
+                - name: value
+                - hosted_zone_name: value
+                - resource_id: value
+                - caller_reference: value
+                - config:
+                    PrivateZone: True
+                    Comment: 'description of hosted zone config'
+                - vpcs:
+                    - VPCId: 'vpc id'
+                      VPCRegion: 'us-east1'
+                - delegation_set_id: 'string'
+                - tags:
+                    - Key: 'tag key'
+                      Value: 'tag value'
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     before = None
@@ -175,7 +202,7 @@ async def present(
 
         # Check if tags needs to be updated
         if tags is not None:
-            update_ret_tags = await hub.exec.aws.route53.tag.update_tags(
+            update_ret_tags = await hub.tool.aws.route53.tag.update_tags(
                 ctx,
                 resource_type="hostedzone",
                 resource_id=resource_id,
@@ -253,7 +280,7 @@ async def present(
                     )
                     return result
         if tags is not None:
-            add_tags = await hub.exec.aws.route53.tag.update_tags(
+            add_tags = await hub.tool.aws.route53.tag.update_tags(
                 ctx,
                 resource_type="hostedzone",
                 resource_id=resource_id,
@@ -286,43 +313,46 @@ async def present(
 
 
 async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]:
-    r"""
-    **Autogenerated function**
+    r"""Deletes a hosted zone.
 
-    Deletes a hosted zone. If the hosted zone was created by another service, such as Cloud Map, see Deleting Public
-    Hosted Zones That Were Created by Another Service in the Amazon Route 53 Developer Guide for information about
-    how to delete it. (The process is the same for public and private hosted zones that were created by another
-    service.) If you want to keep your domain registration but you want to stop routing internet traffic to your
-    website or web application, we recommend that you delete resource record sets in the hosted zone instead of
-    deleting the hosted zone.  If you delete a hosted zone, you can't undelete it. You must create a new hosted zone
-    and update the name servers for your domain registration, which can require up to 48 hours to take effect. (If
-    you delegated responsibility for a subdomain to a hosted zone and you delete the child hosted zone, you must
-    update the name servers in the parent hosted zone.) In addition, if you delete a hosted zone, someone could
-    hijack the domain and route traffic to their own resources using your domain name.  If you want to avoid the
-    monthly charge for the hosted zone, you can transfer DNS service for the domain to a free DNS service. When you
-    transfer DNS service, you have to update the name servers for the domain registration. If the domain is
-    registered with Route 53, see UpdateDomainNameservers for information about how to replace Route 53 name servers
-    with name servers for the new DNS service. If the domain is registered with another registrar, use the method
-    provided by the registrar to update name servers for the domain registration. For more information, perform an
-    internet search on "free DNS service." You can delete a hosted zone only if it contains only the default SOA
-    record and NS resource record sets. If the hosted zone contains other resource record sets, you must delete them
-    before you can delete the hosted zone. If you try to delete a hosted zone that contains other resource record
-    sets, the request fails, and Route 53 returns a HostedZoneNotEmpty error. For information about deleting records
-    from your hosted zone, see ChangeResourceRecordSets. To verify that the hosted zone has been deleted, do one of
-    the following:   Use the GetHostedZone action to request information about the hosted zone.   Use the
+    If the hosted zone was created by another service, such as Cloud Map, see Deleting Public Hosted Zones That Were
+    Created by Another Service in the Amazon Route 53 Developer Guide for information about how to delete it.
+    (The process is the same for public and private hosted zones that were created by another service.) If you want to
+    keep your domain registration but you want to stop routing internet traffic to your website or web application, we
+    recommend that you delete resource record sets in the hosted zone instead of deleting the hosted zone.  If you delete
+    a hosted zone, you can't undelete it. You must create a new hosted zone and update the name servers for your domain
+    registration, which can require up to 48 hours to take effect. (If you delegated responsibility for a subdomain to a
+    hosted zone and you delete the child hosted zone, you must update the name servers in the parent hosted zone.)
+
+    In addition, if you delete a hosted zone, someone could hijack the domain and route traffic to their own resources using
+    your domain name.  If you want to avoid the monthly charge for the hosted zone, you can transfer DNS service for the
+    domain to a free DNS service. When you transfer DNS service, you have to update the name servers for the domain
+    registration. If the domain is registered with Route 53, see UpdateDomainNameservers for information about how to replace
+    Route 53 name servers with name servers for the new DNS service. If the domain is registered with another registrar,
+    use the method provided by the registrar to update name servers for the domain registration.
+
+    For more information, perform an internet search on "free DNS service." You can delete a hosted zone only if it
+    contains only the default SOA record and NS resource record sets. If the hosted zone contains other resource record
+    sets, you must delete them before you can delete the hosted zone. If you try to delete a hosted zone that contains
+    other resource record sets, the request fails, and Route 53 returns a HostedZoneNotEmpty error. For information about
+    deleting records from your hosted zone, see ChangeResourceRecordSets. To verify that the hosted zone has been deleted,
+    do one of the following:   Use the GetHostedZone action to request information about the hosted zone.   Use the
     ListHostedZones action to get a list of the hosted zones associated with the current Amazon Web Services
     account.
 
     Args:
-        name(Text): An Idem name of the hosted zone resource.
-        resource_id(Text, optional): AWS route53 hosted zone ID. Idem automatically considers this resource being absent
-         if this field is not specified.
+        name(str):
+            An Idem name of the hosted zone resource.
+        resource_id(str, Optional):
+            AWS route53 hosted zone ID. Idem automatically considers this resource being absent if this field is not specified.
 
     Request Syntax:
-        [hosted-zone-name]:
-          aws.route53.hosted_zone.present:
-          - name: 'string'
-          - resource_id: 'string'
+        .. code-block:: sls
+
+            [hosted-zone-name]:
+              aws.route53.hosted_zone.present:
+                - name: 'string'
+                - resource_id: 'string'
 
     Returns:
         Dict[str, Any]
@@ -377,16 +407,11 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""
-    **Autogenerated function**
-
-    Describe the resource in a way that can be recreated/managed with the corresponding "present" function
-
+    r"""Describe the resource in a way that can be recreated/managed with the corresponding "present" function
 
     Retrieves a list of the public and private hosted zones that are associated with the current Amazon Web Services
     account.
 
-
     Returns:
         Dict[str, Any]
 
@@ -443,28 +468,42 @@ async def search(
     This function has been deprecated. Please use exec.run with aws.route53.hosted_zone.get instead.
 
     Args:
-        name(string): The name of the Idem state.
-        hosted_zone_name(string, optional): The domain name of hosted_zone
-        resource_id(string, optional): AWS hosted_zone id to filter the resource.If resource_id is mentioned then we
-                                       directly return the resource without checking other filters
-        private_zone(bool, optional): Bool argument to specify a private hosted_zone. One of the filter option for hosted_zone
-        vpc_id(string, optional):The vpc_id associated with the hosted_zone.One of the filter option for hosted_zone
-        tags(List, optional): Tags of the hosted_zone. One of the filter option for hosted_zone
+        name(str):
+            The name of the Idem state.
+
+        hosted_zone_name(str, Optional):
+            The domain name of hosted_zone
+
+        resource_id(str, Optional):
+            AWS hosted_zone id to filter the resource.If resource_id is mentioned then we directly return the resource
+            without checking other filters
+
+        private_zone(bool, Optional):
+            Bool argument to specify a private hosted_zone. One of the filter option for hosted_zone
+
+        vpc_id(str, Optional):
+            The vpc_id associated with the hosted_zone.One of the filter option for hosted_zone
+
+        tags(list, Optional):
+            Tags of the hosted_zone. One of the filter option for hosted_zone
 
 
     Request Syntax:
-        [Idem-state-name]:
-          aws.route53.hosted_zone.search:
-          - hosted_zone_name: 'string'
-          - resource_id: 'string'
-          - private_zone: 'bool'
-          - vpc_id: 'string'
-          - tags: 'List'
+        .. code-block:: sls
+
+            [Idem-state-name]:
+              aws.route53.hosted_zone.search:
+                - hosted_zone_name: 'string'
+                - resource_id: 'string'
+                - private_zone: 'bool'
+                - vpc_id: 'string'
+                - tags: 'List'
 
     Returns:
-        {"comment": A message tuple, "old_state": Dict, "new_state": Dict, "name": string, "result": bool}
+        Dict[str, Any]
 
-        Examples:
+    Examples:
+        .. code-block:: sls
 
             my-unmanaged-hosted_zone:
               aws.route53.hosted_zone.search:
@@ -473,8 +512,8 @@ async def search(
                 - private_zone: false
                 - vpc_id: vpc-0e87ce8f2c3317d53
                 - tags:
-                  - Key: Name
-                    Value: idem-test-hosted_zone
+                    - Key: Name
+                      Value: idem-test-hosted_zone
 
     """
 
