@@ -216,7 +216,9 @@ async def present(
             tags_list = tags
             tags_dict = hub.tool.aws.tag_utils.convert_tag_list_to_dict(tags)
     if resource_id:
-        resource = hub.tool.boto3.resource.create(ctx, "s3", "Bucket", resource_id)
+        resource = await hub.tool.boto3.resource.create(
+            ctx, "s3", "Bucket", resource_id
+        )
         before = await hub.tool.boto3.resource.describe(resource)
     if before:
         convert_ret = await hub.exec.aws.s3.bucket.get(
@@ -385,7 +387,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
             resource_type="aws.s3.bucket", name=name
         )
         return result
-    resource = hub.tool.boto3.resource.create(ctx, "s3", "Bucket", resource_id)
+    resource = await hub.tool.boto3.resource.create(ctx, "s3", "Bucket", resource_id)
     before = await hub.tool.boto3.resource.describe(resource)
 
     if not before:
