@@ -20,7 +20,12 @@ async def modify(
 
     ctx = dict_tools.data.NamespaceDict(acct=new_profile, test=False)
 
-    credentials = await hub.exec.aws.sts.assume_role.credentials(ctx, **assume_role_obj)
+    try:
+        credentials = await hub.exec.aws.sts.assume_role.credentials(
+            ctx, **assume_role_obj
+        )
+    except Exception as e:
+        raise ConnectionError(f"Failed to assume role: {e.__class__.__name__}:{e}")
 
     if not credentials.result:
         # Failed to assume the role, don't allow a half-baked profile to be used
