@@ -13,7 +13,7 @@ def convert_raw_launch_configuration_to_present(
     resource_id = raw_resource.get("LaunchConfigurationName")
     resource_parameters = OrderedDict(
         {
-            "LaunchConfigurationName": "name",
+            "LaunchConfigurationName": "launch_config_name",
             "ImageId": "image_id",
             "KeyName": "key_name",
             "SecurityGroups": "security_groups",
@@ -39,9 +39,27 @@ def convert_raw_launch_configuration_to_present(
         if parameter_raw in raw_resource and raw_resource.get(parameter_raw):
             resource_translated[parameter_present] = raw_resource.get(parameter_raw)
 
+    resource_translated = (
+        hub.tool.aws.autoscaling.conversion_utils.handle_security_groups(
+            resource=resource_translated
+        )
+    )
     return resource_translated
 
 
+def handle_security_groups(hub, resource):
+    # security_groups and classic_link_vpc_security_groups are of type List(str)
+    # Just the change in the order of their elements should not be considered as a difference in new state and old state
+    # So sorting the values for security_groups and classic_link_vpc_security_groups.
+    if resource.get("security_groups"):
+        resource["security_groups"] = sorted(resource["security_groups"])
+    if resource.get("classic_link_vpc_security_groups"):
+        resource["classic_link_vpc_security_groups"] = sorted(
+            resource["classic_link_vpc_security_groups"]
+        )
+    return resource
+
+
 def convert_raw_scaling_policy_to_present(
     hub, ctx, raw_resource: Dict[str, Any]
 ) -> Dict[str, Any]:
