@@ -301,6 +301,53 @@ def convert_raw_flow_log_to_present(hub, flow_log: Dict):
     return translated_flow_log
 
 
+def convert_raw_route_to_present(
+    hub, raw_resource: Dict, route_table_id: str, idem_resource_name: str = None
+) -> Dict[str, Any]:
+    describe_parameters = OrderedDict(
+        {
+            "DestinationCidrBlock": "destination_cidr_block",
+            "DestinationIpv6CidrBlock": "destination_ipv6_cidr_block",
+            "DestinationPrefixListId": "destination_prefix_list_id",
+            "EgressOnlyInternetGatewayId": "egress_only_internet_gateway_id",
+            "GatewayId": "gateway_id",
+            "InstanceId": "instance_id",
+            "InstanceOwnerId": "instance_owner_id",
+            "NatGatewayId": "nat_gateway_id",
+            "TransitGatewayId": "transit_gateway_id",
+            "LocalGatewayId": "local_gateway_id",
+            "CarrierGatewayId": "carrier_gateway_id",
+            "NetworkInterfaceId": "network_interface_id",
+            "VpcPeeringConnectionId": "vpc_peering_connection_id",
+            "CoreNetworkArn": "core_network_arn",
+        }
+    )
+    if not raw_resource:
+        return {}
+    resource_id = f"{route_table_id}/{(raw_resource.get('DestinationCidrBlock') or raw_resource.get('DestinationIpv6CidrBlock') or raw_resource.get('DestinationPrefixListId'))}"
+    resource_translated = {
+        "name": idem_resource_name,
+        "resource_id": resource_id,
+        "route_table_id": route_table_id,
+    }
+
+    for parameter_old_key, parameter_new_key in describe_parameters.items():
+        if raw_resource.get(parameter_old_key) is not None:
+            # vpc_endpoint_id is sent in gateway id field. we have to check if it starts with vpce- and update
+            # vpc_endpoint_id field.
+            if "gateway_id" == parameter_new_key and raw_resource.get(
+                parameter_old_key
+            ).startswith("vpce-"):
+                resource_translated["vpc_endpoint_id"] = raw_resource.get(
+                    parameter_old_key
+                )
+            else:
+                resource_translated[parameter_new_key] = raw_resource.get(
+                    parameter_old_key
+                )
+    return resource_translated
+
+
 def convert_raw_route_table_to_present(
     hub, raw_resource: Dict, idem_resource_name: str = None
 ) -> Dict[str, Any]:
@@ -768,6 +815,11 @@ def convert_raw_volume_to_present(
         if raw_resource.get(parameter_raw):
             resource_translated[parameter_present] = raw_resource.get(parameter_raw)
 
+    if "CreateTime" in raw_resource:
+        local_time = raw_resource.get("CreateTime").astimezone()
+        start_time = local_time.astimezone(timezone.utc).strftime(UTC_FORMAT)
+        resource_translated["create_time"] = start_time
+
     if "Tags" in raw_resource:
         resource_translated["tags"] = hub.tool.aws.tag_utils.convert_tag_list_to_dict(
             raw_resource.get("Tags")
@@ -805,3 +857,18 @@ def convert_raw_vpc_peering_connection_options_to_present(
     }
 
     return resource_translated
+
+
+def convert_raw_vpc_peering_connection_accepter_to_present(
+    hub, raw_resource: Dict[str, Any], idem_resource_name: str
+) -> Dict[str, Any]:
+    if not raw_resource:
+        return {}
+
+    resource_translated = {
+        "resource_id": raw_resource["VpcPeeringConnectionId"],
+        "name": idem_resource_name,
+        "connection_status": raw_resource["Status"]["Code"],
+    }
+
+    return resource_translated
