@@ -78,3 +78,30 @@ def convert_raw_repository_policy_to_present(
         )
 
     return resource_translated
+
+
+def convert_raw_image_to_present(
+    hub, raw_resource: Dict[str, Any], idem_resource_name: str = None
+) -> Dict[str, Any]:
+    resource_parameters = OrderedDict(
+        {
+            "registryId": "registry_id",
+            "repositoryName": "repository_name",
+            "imageDigest": "image_digest",
+            "imageTags": "image_tags",
+            "imageSizeInBytes": "image_size_in_bytes",
+            "imageScanStatus": "image_scan_status",
+            "imageScanFindingsSummary": "image_scan_findings_summary",
+            "imageManifestMediaType": "image_manifest_media_type",
+            "artifactMediaType": "artifact_media_type",
+        }
+    )
+
+    resource_translated = {}
+    if idem_resource_name:
+        resource_translated["name"] = idem_resource_name
+    for parameter_raw, parameter_present in resource_parameters.items():
+        if parameter_raw in raw_resource and raw_resource.get(parameter_raw):
+            resource_translated[parameter_present] = raw_resource.get(parameter_raw)
+
+    return resource_translated
