@@ -69,15 +69,8 @@ def convert_raw_topic_to_present(
 
     attributes = {}
     for param in attribute_params:
-        value = raw_attributes.get(param, None)
-        if value:
-            if isinstance(value, str):
-                try:
-                    attributes[param] = json.loads(value)
-                except JSONDecodeError:
-                    attributes[param] = value
-            else:
-                attributes[param] = standardise_json(hub, value)
+        if raw_attributes.get(param):
+            attributes[param] = raw_attributes.get(param)
     resource_translated["attributes"] = attributes
 
     if raw_resource_tags.get("ret") and raw_resource_tags.get("ret").get("Tags"):
